@@ -2,26 +2,10 @@
 from __future__ import annotations
 
 import asyncio
-from collections import defaultdict
-from copy import deepcopy
-from datetime import datetime
-from enum import Enum
-from functools import partial
-import json
 import logging
-from operator import itemgetter
 import pprint
 from types import TracebackType
-from typing import (
-    TYPE_CHECKING,
-    Any,
-    Callable,
-    DefaultDict,
-    Dict,
-    List,
-    NoReturn,
-    Optional,
-)
+from typing import TYPE_CHECKING, Any, Callable, Dict, NoReturn, Optional
 import uuid
 
 from aiohttp import ClientSession, ClientWebSocketResponse, WSMsgType, client_exceptions
@@ -31,8 +15,7 @@ from ..common.helpers.util import (
     chip_clusters_version,
     dataclass_from_dict,
     dataclass_to_dict,
-    parse_value,
-    parse_message
+    parse_message,
 )
 from ..common.models.api_command import APICommand
 from ..common.models.events import EventType
@@ -126,7 +109,7 @@ class MatterClient:
             # if start_listening is called this dict will be kept up to date
             return list(self._nodes.values())
         data = await self.send_command(APICommand.GET_NODES)
-        return [MatterNode.from_dict(x) for x in data]
+        return [dataclass_from_dict(MatterNode, x) for x in data]
 
     async def get_node(self, node_id: int) -> MatterNode:
         """Return Matter node by id."""
@@ -134,7 +117,7 @@ class MatterClient:
             # if start_listening is called this dict will be kept up to date
             return self._nodes[node_id]
         data = await self.send_command(APICommand.GET_NODE, node_id=node_id)
-        return MatterNode.from_dict(data)
+        return dataclass_from_dict(MatterNode, data)
 
     async def commission_with_code(self, code: str) -> MatterNode:
         """
@@ -143,7 +126,7 @@ class MatterClient:
         Returns full NodeInfo once complete.
         """
         data = await self.send_command(APICommand.COMMISSION_WITH_CODE, code=code)
-        return MatterNode.from_dict(data)
+        return dataclass_from_dict(MatterNode, data)
 
     async def commission_on_network(self, setup_pin_code: int) -> MatterNode:
         """
@@ -154,7 +137,7 @@ class MatterClient:
         data = await self.send_command(
             APICommand.COMMISSION_ON_NETWORK, setup_pin_code=setup_pin_code
         )
-        return MatterNode.from_dict(data)
+        return dataclass_from_dict(MatterNode, data)
 
     async def set_wifi_credentials(self, ssid: str, credentials: str) -> None:
         """Set WiFi credentials for commissioning to a (new) device."""
@@ -197,7 +180,7 @@ class MatterClient:
             APICommand.DEVICE_COMMAND,
             node_id=node_id,
             endpoint=endpoint,
-            payload=payload
+            payload=payload,
         )
 
     async def remove_node(self, node_id: int) -> None:
@@ -292,9 +275,11 @@ class MatterClient:
         if self.server_info.schema_version > MIN_SCHEMA_VERSION:
             # server version is higher than expected, log only
             self.logger.warning(
-                f"Matter Server detedted with schema version {info.schema_version} "
-                f"which is higher than the preferred api schema {MIN_SCHEMA_VERSION} of this client"
-                " - you may run into compatibility issues."
+                "Matter Server detected with schema version %s "
+                "which is higher than the preferred api schema %s of this client"
+                " - you may run into compatibility issues.",
+                info.schema_version,
+                MIN_SCHEMA_VERSION,
             )
 
         self.logger.info(
