@@ -4,62 +4,33 @@ from __future__ import annotations
 
 import asyncio
 from collections import deque
-from concurrent import futures
 from datetime import datetime
-from enum import IntEnum
 from functools import partial
 import logging
-import os
-from typing import (
-    TYPE_CHECKING,
-    Any,
-    Callable,
-    Coroutine,
-    Deque,
-    Final,
-    Generator,
-    List,
-    Optional,
-    Tuple,
-    Type,
-    Union,
-    cast,
-)
+from typing import TYPE_CHECKING, Any, Callable, Deque, Optional, Type
 
 from chip.ChipDeviceCtrl import ChipDeviceController
-from chip.clusters import (
-    Attribute,
-    Cluster,
-    ClusterAttributeDescriptor,
-    ClusterCommand,
-    ClusterEvent,
-)
+from chip.clusters import Attribute, ClusterCommand
 from chip.discovery import FilterType as DiscoveryFilterType
 from chip.exceptions import ChipStackError
 
 from ..common.helpers.api import api_command
-from ..common.helpers.util import dataclass_from_dict, dataclass_to_dict
+from ..common.helpers.util import dataclass_from_dict
 from ..common.models.api_command import APICommand
 from ..common.models.error import (
     NodeCommissionFailed,
     NodeInterviewFailed,
     NodeNotExists,
+    NodeNotResolving,
     SDKCommandFailed,
 )
 from ..common.models.events import EventType
-from ..common.models.message import (
-    CommandMessage,
-    ErrorResultMessage,
-    SuccessResultMessage,
-)
 from ..common.models.node import MatterAttribute, MatterNode
 from .const import SCHEMA_VERSION
 
 if TYPE_CHECKING:
 
     from .server import MatterServer
-    from .stack import MatterStack
-
 
 DATA_KEY_NODES = "nodes"
 DATA_KEY_LAST_NODE_ID = "last_node_id"
@@ -105,7 +76,10 @@ class MatterDeviceController:
             node = dataclass_from_dict(MatterNode, node_dict)
             self._nodes[node_id] = node
             # make sure to start node subscriptions
-            await self.subscribe_node(node_id)
+            try:
+                await self.subscribe_node(node_id)
+            except NodeNotResolving:
+                LOGGER.warning("Node %s is not resolving, skipping...", node_id)
         # create task to check for nodes that need any re(interviews)
         self.server.loop.create_task(self._check_interviews())
         LOGGER.debug("CHIP Device Controller Initialized")
@@ -139,17 +113,22 @@ class MatterDeviceController:
         Returns full NodeInfo once complete.
         """
         node_id = self._get_next_node_id()
-        success = await self._call_sdk(
-            self.chip_controller.CommissionWithCode,
-            setupPayload=code,
-            nodeid=node_id,
-        )
 
         # TODO TEMP !!!
         # The call to CommissionWithCode returns early without waiting ?!
         # This is most likely a bug in the SDK or its python wrapper
+        # success = await self._call_sdk(
+        #     self.chip_controller.CommissionWithCode,
+        #     setupPayload=code,
+        #     nodeid=node_id,
+        # )
         # if not success:
         #     raise NodeCommissionFailed(f"CommissionWithCode failed for node {node_id}")
+        await self._call_sdk(
+            self.chip_controller.CommissionWithCode,
+            setupPayload=code,
+            nodeid=node_id,
+        )
         await asyncio.sleep(60)
 
         # full interview of the device
@@ -164,13 +143,14 @@ class MatterDeviceController:
         self,
         setup_pin_code: int,
         filter_type: DiscoveryFilterType = DiscoveryFilterType.NONE,
-        filter: Any = None,
+        filter: Any = None,  # pylint: disable=redefined-builtin
     ) -> MatterNode:
         """
         Commission a device already connected to the network.
 
         Does the routine for OnNetworkCommissioning, with a filter for mDNS discovery.
-        The filter can be an integer, a string or None depending on the actual type of selected filter.
+        The filter can be an integer,
+        a string or None depending on the actual type of selected filter.
         Returns full NodeInfo once complete.
         """
         node_id = self._get_next_node_id()
@@ -201,8 +181,7 @@ class MatterDeviceController:
 
         if error_code != 0:
             raise SDKCommandFailed("Set WiFi credentials failed.")
-        else:
-            self.wifi_credentials_set = True
+        self.wifi_credentials_set = True
 
     @api_command(APICommand.SET_THREAD_DATASET)
     async def set_thread_operational_dataset(self, dataset: str) -> None:
@@ -214,8 +193,7 @@ class MatterDeviceController:
 
         if error_code != 0:
             raise SDKCommandFailed("Set Thread credentials failed.")
-        else:
-            self.thread_credentials_set = True
+        self.thread_credentials_set = True
 
     @api_command(APICommand.OPEN_COMMISSIONING_WINDOW)
     async def open_commissioning_window(
@@ -296,10 +274,9 @@ class MatterDeviceController:
 
     @api_command(APICommand.DEVICE_COMMAND)
     async def send_device_command(
-        self, node_id: int, endpoint: int, cmd: Type[ClusterCommand], args: dict
+        self, node_id: int, endpoint: int, payload: ClusterCommand
     ) -> Any:
         """Send a command to a Matter node/device."""
-        payload = cmd.FromDict(args)
         return await self.chip_controller.SendCommand(
             nodeid=node_id, endpoint=endpoint, payload=payload
         )
@@ -332,7 +309,10 @@ class MatterDeviceController:
         assert node_id not in self._subscriptions, "Already subscribed to node"
         LOGGER.debug("Setup subscription for node %s", node_id)
 
-        await self._call_sdk(self.chip_controller.ResolveNode, nodeid=node_id)
+        try:
+            await self._call_sdk(self.chip_controller.ResolveNode, nodeid=node_id)
+        except ChipStackError as err:
+            raise NodeNotResolving(f"Failed to resolve node {node_id}") from err
         # we follow the pattern of apple and google here and
         # just do a wildcard subscription for all clusters and properties
         # the client will handle filtering of the events.
@@ -368,6 +348,7 @@ class MatterDeviceController:
             data: Attribute.EventReadResult,
             transaction: Attribute.SubscriptionTransaction,
         ):
+            # pylint: disable=unused-argument
             LOGGER.debug("received node event: %s", data)
             self.event_history.append(data)
             # TODO: This callback does not seem to fire ever or my test devices do not have events
@@ -378,6 +359,7 @@ class MatterDeviceController:
         def error_callback(
             chipError: int, transaction: Attribute.SubscriptionTransaction
         ):
+            # pylint: disable=unused-argument, invalid-name
             LOGGER.error("Got error fron node: %s", chipError)
 
         def resubscription_attempted(
@@ -385,6 +367,7 @@ class MatterDeviceController:
             terminationError: int,
             nextResubscribeIntervalMsec: int,
         ):
+            # pylint: disable=unused-argument, invalid-name
             LOGGER.debug(
                 "Previous subscription failed with Error: %s - re-subscribing in %s ms...",
                 terminationError,
@@ -393,7 +376,8 @@ class MatterDeviceController:
             # TODO: update node status to unavailable
 
         def resubscription_succeeded(transaction: Attribute.SubscriptionTransaction):
-            LOGGER.debug(f"Subscription succeeded")
+            # pylint: disable=unused-argument, invalid-name
+            LOGGER.debug("Subscription succeeded")
             # TODO: update node status to available
 
         sub.SetAttributeUpdateCallback(attribute_updated_callback)
@@ -407,7 +391,6 @@ class MatterDeviceController:
         """Return next node_id."""
         next_node_id = self.server.storage.get(DATA_KEY_LAST_NODE_ID, 0) + 1
         self.server.storage.set(DATA_KEY_LAST_NODE_ID, next_node_id, force=True)
-        self._last_nodeid = next_node_id
         return next_node_id
 
     async def _call_sdk(self, func: Callable, *args, **kwargs) -> Any:
